Package 'ssdtests'

Title: Tests for ssdtools
Description: Slow and unstable tests for ssdtools package.
Authors: Joe Thorley [aut, cre] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Rebecca Fisher [aut], David Fox [aut], Carl Schwarz [aut], Angeline Tillmanns [ctb], Seb Dalgarno [ctb] (ORCID: <https://orcid.org/0000-0002-3658-4517>), Kathleen McTavish [ctb], Doug Spry [ctb], Rick van Dam [ctb], Graham Batley [ctb], Ali Azizishirazi [ctb], Province of British Columbia [fnd, cph], Environment and Climate Change Canada [fnd, cph], Australian Government Department of Climate Change, Energy, the Environment and Water [fnd, cph]
Maintainer: Joe Thorley <[email protected]>
License: Apache License (== 2.0) | file LICENSE
Version: 0.1.0
Built: 2026-06-06 05:08:20 UTC
Source: https://github.com/poissonconsulting/ssdtests

Help Index


Pearson 1000 Data

Description

An example tibble of 1000 values simulated using a Pearson distribution.

Usage

pearson1000

Format

A tbl data frame that includes:

Conc

A numeric vector of the simulate concentrations.

Examples

head(pearson1000)

Licensing Markdown

Description

A string of markdown code indicating the licensing of the code and documentation

Usage

ssdtests_licensing_md()

Examples

ssdtests_licensing_md()